[ARVADOS] created: 1.3.0-2248-g643b160f9

Git user git at public.arvados.org
Thu Mar 5 19:45:30 UTC 2020


        at  643b160f9af9a245607d4cbee488d08f8516df5e (commit)


commit 643b160f9af9a245607d4cbee488d08f8516df5e
Author: Tom Clegg <tom at tomclegg.ca>
Date:   Thu Mar 5 14:44:22 2020 -0500

    16219: Load all fields needed to compute node size.
    
    Without ContainerImage and Mounts, the scratch size requirement can't
    be computed correctly.
    
    Arvados-DCO-1.1-Signed-off-by: Tom Clegg <tom at tomclegg.ca>

diff --git a/lib/dispatchcloud/container/queue.go b/lib/dispatchcloud/container/queue.go
index a4a270dd1..d128c265f 100644
--- a/lib/dispatchcloud/container/queue.go
+++ b/lib/dispatchcloud/container/queue.go
@@ -26,8 +26,9 @@ type APIClient interface {
 // A QueueEnt is an entry in the queue, consisting of a container
 // record and the instance type that should be used to run it.
 type QueueEnt struct {
 	// The container to run. Only the UUID, State, Priority, and
 	// RuntimeConstraints fields are populated.
 	Container    arvados.Container    `json:"container"`
 	InstanceType arvados.InstanceType `json:"instance_type"`
 }
@@ -381,7 +382,7 @@ func (cq *Queue) poll() (map[string]*arvados.Container, error) {
 			*next[upd.UUID] = upd
 		}
 	}
-	selectParam := []string{"uuid", "state", "priority", "runtime_constraints"}
+	selectParam := []string{"uuid", "state", "priority", "runtime_constraints", "container_image", "mounts"}
 	limitParam := 1000
 
 	mine, err := cq.fetchAll(arvados.ResourceListParams{

-----------------------------------------------------------------------
@@ -26,8 +26,9 @@ type APIClient interface {
 // record and the instance type that should be used to run it.
 type QueueEnt struct {
-	// The container to run. Only the UUID, State, Priority, and
-	// RuntimeConstraints fields are populated.
+	// The container to run. Only the UUID, State, Priority,
+	// RuntimeConstraints, Mounts, and ContainerImage fields are
+	// populated.
 	Container    arvados.Container    `json:"container"`
 	InstanceType arvados.InstanceType `json:"instance_type"`


hooks/post-receive
-- 




More information about the arvados-commits mailing list